@@ -631,7 +631,7 @@ class DebugNotification(Command):
 
     def job(
         self,
-        job_id: str,
+        job_id: UUID_EXPANSION,
         *,
         report_container_type: ContainerType = ContainerType.unique_reports,
         crash_name: str = "fake-crash-sample",
@@ -655,7 +655,7 @@ class DebugNotification(Command):
 
     def task(
         self,
-        task_id: str,
+        task_id: UUID_EXPANSION,
         *,
         report_container_type: ContainerType = ContainerType.unique_reports,
         crash_name: str = "fake-crash-sample",
